@@ -2,8 +2,9 @@ __title__ = 'Amino.ed'
 __author__ = 'Alert Aigul'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2020-2021 Alert'
-__version__ = '1.2.20'
+__version__ = '1.2.21.1'
 
+from .lib import util
 from .acm import ACM
 from .client import Client
 from .sub_client import SubClient
