@@ -7,6 +7,10 @@ class DeviceGenerator:
             with open("device.json", "r") as stream:
                 data = json.load(stream)
 
+                self.sig = data["device_id_sig"]
+
+                self.user_agent = data["user_agent"]
+
                 if deviceId:
                     self.device_id = deviceId
                 else:
@@ -20,8 +24,11 @@ class DeviceGenerator:
             with open("device.json", "r") as stream:
                 data = json.load(stream)
 
+                self.sig = data["device_id_sig"]
+                
+                self.user_agent = data["user_agent"]
+
                 if deviceId:
                     self.device_id = deviceId
                 else:
                     self.device_id = data["device_id"]
-
