@@ -1,10 +1,30 @@
 from amino.lib.util import device
 
+
 sid = None
 
-
 class Headers:
-    def __init__(self, data=None, type=None, deviceId: str = None, sig: str = None):
+    def __init__(self, data = None, type = None, deviceId: str = None, sig: str = None):
+        dev = device.DeviceGenerator(deviceId=deviceId if deviceId else None)
+
+        headers = {
+            "NDCDEVICEID": dev.device_id,
+            "NDC-MSG-SIG": sig if sig else dev.sig,
+            "Accept-Language": "en-US",
+            "Content-Type": "text/javascript; charset=UTF-8",
+            "User-Agent": dev.user_agent,
+            "Host": "service.narvii.com",
+            "Accept-Encoding": "gzip",
+            "Connection": "Upgrade"
+        }
+
+        if data: headers["Content-Length"] = str(len(data))
+        if sid: headers["NDCAUTH"] = f"sid={sid}"
+        if type: headers["Content-Type"] = type
+        self.headers = headers
+
+class ApipHeaders:
+    def __init__(self, type=None, deviceId: str = None):
         dev = device.DeviceGenerator(deviceId=deviceId if deviceId else None)
 
         headers = {
@@ -13,8 +33,8 @@ class Headers:
 
         if sid:
             headers["NDCAUTH"] = f"sid={sid}"
-        if sig:
-            headers["NDC-MSG-SIG"] = sig
+        if type:
+            headers["Content-Type"] = type
         self.headers = headers
 
 class WebHeaders:
@@ -28,4 +48,4 @@ class WebHeaders:
 
         if coockie:
             web_headers["cookie"] = coockie
-        self.headers = web_headers
\ No newline at end of file
+        self.headers = web_headers
